@@ -8,9 +8,9 @@ Please find a description of this package at:
 
 Author: Ilan Schnell
 """
-from ._bitarray import _bitarray, bits2bytes, _sysinfo
+from bitarray._bitarray import _bitarray, bitdiff, bits2bytes, _sysinfo
 
-__version__ = '0.7.0'
+__version__ = '0.8.2'
 
 
 def _tree_insert(tree, sym, ba):
@@ -118,11 +118,20 @@ with the corresponding bitarray for each symbols."""
         _check_codedict(codedict)
         self._encode(codedict, iterable)
 
+    def __int__(self):
+        raise TypeError("int() argument cannot be a bitarray")
+
+    def __long__(self):
+        raise TypeError("long() argument cannot be a bitarray")
+
+    def __float__(self):
+        raise TypeError("float() argument cannot be a bitarray")
+
 
 def test(verbosity=1, repeat=1):
     """test(verbosity=1, repeat=1) -> TextTestResult
 
 Run self-test, and return unittest.runner.TextTestResult object.
 """
-    from . import test_bitarray
+    from bitarray import test_bitarray
     return test_bitarray.run(verbosity=verbosity, repeat=repeat)
